@@ -43,6 +43,9 @@ def color_fmt(colors):
     ):  # NOQA
         # colors is just one element
         colors = [colors]
+    if len(colors) == 0:
+        # empty colors
+        return None
     color = colors[0]
     norm_types = (int, float, np.float32, np.float64, np.integer)
 
@@ -252,7 +255,9 @@ def norm_to_rgba(scalars, cmap=None, vmin=None, vmax=None):
     return colors
 
 
-def rgba_to_norm(colors, cmap, vmin, vmax, max_distance=1e-6):
+def rgba_to_norm(
+    colors, cmap, vmin, vmax, max_distance=1e-6, normalizer=mpl.colors.Normalize
+):
     """
     Inverse 'norm_to_rgba'
     Reconstruct the numeric values (0 - 1) of given
@@ -270,7 +275,7 @@ def rgba_to_norm(colors, cmap, vmin, vmax, max_distance=1e-6):
     colors = colors.view(np.float64).reshape(colors.shape + (-1,))
 
     rnge = np.linspace(vmin, vmax, 256)
-    norm = mpl.colors.Normalize(vmin, vmax)
+    norm = normalizer(vmin, vmax)
     if isinstance(cmap, str):
         cmap = mpl.cm.get_cmap(cmap)
     mapvals = cmap(norm(rnge))[:, :4]  # there are 4 channels: r,g,b,a
